-------------
 Field Types
-------------

string:
    a string of unicode text.
text:
    a longer block of unicode text; 
integer:
    .
float:
    .
decimal:
    .
timestamp:
    .
boolean:
    .
file:
    .
url:
    .
list:
    .
yaml:
    .
